@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 # vim:ts=4:noet
 #
-# Runs unittests for automx2. Example usage:
+# Runs unittests for Fangfrisch. Example usage:
 #
 # (1) unittest.sh
 # Run all unittests without collecting coverage data.
@@ -25,7 +25,7 @@ CONF='tests/tests.conf'
 sed -i'' -e "s,^db_url.*,db_url = sqlite:///${DB}," $CONF
 
 function usage() {
-	echo "Usage: $(basename $0) [coverage]" >&2
+	echo "Usage: $(basename "$0") [coverage]" >&2
 	exit 1
 }
 
