@@ -32,6 +32,8 @@ from fangfrisch.config import LOG_LEVEL
 from fangfrisch.config import LOG_METHOD
 from fangfrisch.config import LOG_TARGET
 from fangfrisch.config import MAX_SIZE
+from fangfrisch.config.fangfrischnews import fangfrischnews
+from fangfrisch.config.interserver import interserver
 from fangfrisch.config.malwarepatrol import malwarepatrol
 from fangfrisch.config.sanesecurity import sanesecurity
 from fangfrisch.config.securiteinfo import securiteinfo
@@ -61,7 +63,14 @@ class Configuration:
             MAX_SIZE: '10MB',
         }
         self.parser = ConfigParser(defaults=defaults, interpolation=ExtendedInterpolation())
-        for dict_ in [malwarepatrol, sanesecurity, securiteinfo, urlhaus]:
+        for dict_ in [
+            fangfrischnews,
+            interserver,
+            malwarepatrol,
+            sanesecurity,
+            securiteinfo,
+            urlhaus,
+        ]:
             self.parser.read_dict(dict_)
         if filename:
             parsed = self.parser.read([filename])
@@ -86,11 +95,11 @@ class Configuration:
         # No default
         return self.parser.get(configparser.DEFAULTSECT, DB_URL)
 
-    def on_update_exec(self, fallback='') -> str:
-        return self.parser.get(configparser.DEFAULTSECT, 'on_update_exec', fallback=fallback)
+    def on_update_exec(self, section: str = configparser.DEFAULTSECT, fallback='') -> str:
+        return self.parser.get(section, 'on_update_exec', fallback=fallback)
 
-    def on_update_timeout(self, fallback=30) -> int:
-        return self.parser.getint(configparser.DEFAULTSECT, 'on_update_timeout', fallback=fallback)
+    def on_update_timeout(self, section: str = configparser.DEFAULTSECT, fallback=30) -> int:
+        return self.parser.getint(section, 'on_update_timeout', fallback=fallback)
 
     def is_enabled(self, section: str, fallback=False) -> bool:
         # Default: see init() method
