@@ -29,7 +29,8 @@ securiteinfo = {
         '!url_0hour': f'${{{PREFIX}}}securiteinfo0hour.hdb',
         '!url_old': f'${{{PREFIX}}}securiteinfoold.hdb',
         '!url_securiteinfo_mdb': f'${{{PREFIX}}}securiteinfo.mdb',
-        '!url_spam_marketing': f'${{{PREFIX}}}spam_marketing.ndb',
+        '!url_securiteinfo_pdb': f'${{{PREFIX}}}securiteinfo.pdb',
+        '!url_securiteinfo_yara': f'${{{PREFIX}}}securiteinfo.yara',
         'url_android': f'${{{PREFIX}}}securiteinfoandroid.hdb',
         'url_ascii': f'${{{PREFIX}}}securiteinfoascii.hdb',
         'url_html': f'${{{PREFIX}}}securiteinfohtml.hdb',
@@ -37,5 +38,6 @@ securiteinfo = {
         'url_pdf': f'${{{PREFIX}}}securiteinfopdf.hdb',
         'url_securiteinfo': f'${{{PREFIX}}}securiteinfo.hdb',
         'url_securiteinfo_ign2': f'${{{PREFIX}}}securiteinfo.ign2',
+        'url_spam_marketing': f'${{{PREFIX}}}spam_marketing.ndb',
     }
 }
